Welcome to PyECVL's documentation!
==================================

PyECVL is a Python wrapper for `ECVL
<https://github.com/deephealthproject/ecvl>`_, the European Computer
Vision Library.

The source code for PyECVL is available on the `GitHub repo
<https://github.com/deephealthproject/pyecvl>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   getting_started
   api/index
   faq


Indices and tables
==================

* :ref:`genindex`
